pub enum ProgressEnd {}Expand description
The event signals the end of the progress reporting with a final message.
This event should only be sent if the corresponding capability supportsProgressReporting is true.