pub enum ProgressUpdate {}Expand description
The event signals that the progress reporting needs to be updated with a new message and/or percentage.
The client does not have to update the UI immediately, but the clients needs to keep track of the message and/or percentage values.
This event should only be sent if the corresponding capability supportsProgressReporting is true.