pub enum BreakpointLocations {}Expand description
The breakpointLocations request returns all possible locations for source breakpoints in a given range.
Clients should only call this request if the corresponding capability supportsBreakpointLocationsRequest is true.