pub enum GotoTargets {}Expand description
This request retrieves the possible goto targets for the specified source location.
These targets can be used in the goto request.
Clients should only call this request if the corresponding capability supportsGotoTargetsRequest is true.