pub enum Initialized {}Expand description
This event indicates that the debug adapter is ready to accept configuration requests (e.g. setBreakpoints, setExceptionBreakpoints).
A debug adapter is expected to send this event when it is ready to accept configuration requests (but not before the initialize request has finished).
The sequence of events/requests is as follows:
- adapters sends
initializedevent (after theinitializerequest has returned) - client sends zero or more
setBreakpointsrequests - client sends one
setFunctionBreakpointsrequest (if corresponding capabilitysupportsFunctionBreakpointsis true) - client sends a
setExceptionBreakpointsrequest if one or moreexceptionBreakpointFiltershave been defined (or ifsupportsConfigurationDoneRequestis not true) - client sends other future configuration requests
- client sends one
configurationDonerequest to indicate the end of the configuration.