Types representing requests, with associated argument and response types.
Enums
- Attach
- The
attachrequest is sent from the client to the debug adapter to attach to a debuggee that is already running. Since attaching is debugger/runtime specific, the arguments for this request are not part of this specification. - Breakpoint
Locations - The
breakpointLocationsrequest returns all possible locations for source breakpoints in a given range. Clients should only call this request if the corresponding capabilitysupportsBreakpointLocationsRequestis true. - Cancel
- The
cancelrequest is used by the client in two situations: - Completions
- Returns a list of possible completions for a given caret position and text.
Clients should only call this request if the corresponding capability
supportsCompletionsRequestis true. - Configuration
Done - This request indicates that the client has finished initialization of the debug adapter.
So it is the last request in the sequence of configuration requests (which was started by the
initializedevent). Clients should only call this request if the corresponding capabilitysupportsConfigurationDoneRequestis true. - Continue
- The request resumes execution of all threads. If the debug adapter supports single thread execution (see capability
supportsSingleThreadExecutionRequests), setting thesingleThreadargument to true resumes only the specified thread. If not all threads were resumed, theallThreadsContinuedattribute of the response should be set to false. - Data
Breakpoint Info - Obtains information on a possible data breakpoint that could be set on an expression or variable.
Clients should only call this request if the corresponding capability
supportsDataBreakpointsis true. - Disassemble
- Disassembles code stored at the provided location.
Clients should only call this request if the corresponding capability
supportsDisassembleRequestis true. - Disconnect
- The
disconnectrequest asks the debug adapter to disconnect from the debuggee (thus ending the debug session) and then to shut down itself (the debug adapter). In addition, the debug adapter must terminate the debuggee if it was started with thelaunchrequest. If anattachrequest was used to connect to the debuggee, then the debug adapter must not terminate the debuggee. This implicit behavior of when to terminate the debuggee can be overridden with theterminateDebuggeeargument (which is only supported by a debug adapter if the corresponding capabilitysupportTerminateDebuggeeis true). - Evaluate
- Evaluates the given expression in the context of the topmost stack frame. The expression has access to any variables and arguments that are in scope.
- Exception
Info - Retrieves the details of the exception that caused this event to be raised.
Clients should only call this request if the corresponding capability
supportsExceptionInfoRequestis true. - Goto
- The request sets the location where the debuggee will continue to run.
This makes it possible to skip the execution of code or to execute code again.
The code between the current location and the goto target is not executed but skipped.
The debug adapter first sends the response and then a
stoppedevent with reasongoto. Clients should only call this request if the corresponding capabilitysupportsGotoTargetsRequestis true (because only then goto targets exist that can be passed as arguments). - Goto
Targets - This request retrieves the possible goto targets for the specified source location.
These targets can be used in the
gotorequest. Clients should only call this request if the corresponding capabilitysupportsGotoTargetsRequestis true. - Initialize
- The
initializerequest is sent as the first request from the client to the debug adapter in order to configure it with client capabilities and to retrieve capabilities from the debug adapter. Until the debug adapter has responded with aninitializeresponse, the client must not send any additional requests or events to the debug adapter. In addition the debug adapter is not allowed to send any requests or events to the client until it has responded with aninitializeresponse. Theinitializerequest may only be sent once. - Launch
- This launch request is sent from the client to the debug adapter to start the debuggee with or without debugging (if
noDebugis true). Since launching is debugger/runtime specific, the arguments for this request are not part of this specification. - Loaded
Sources - Retrieves the set of all sources currently loaded by the debugged process.
Clients should only call this request if the corresponding capability
supportsLoadedSourcesRequestis true. - Modules
- Modules can be retrieved from the debug adapter with this request which can either return all modules or a range of modules to support paging.
Clients should only call this request if the corresponding capability
supportsModulesRequestis true. - Next
- The request executes one step (in the given granularity) for the specified thread and allows all other threads to run freely by resuming them.
If the debug adapter supports single thread execution (see capability
supportsSingleThreadExecutionRequests), setting thesingleThreadargument to true prevents other suspended threads from resuming. The debug adapter first sends the response and then astoppedevent (with reasonstep) after the step has completed. - Pause
- The request suspends the debuggee.
The debug adapter first sends the response and then a
stoppedevent (with reasonpause) after the thread has been paused successfully. - Read
Memory - Reads bytes from memory at the provided location.
Clients should only call this request if the corresponding capability
supportsReadMemoryRequestis true. - Restart
- Restarts a debug session. Clients should only call this request if the corresponding capability
supportsRestartRequestis true. If the capability is missing or has the value false, a typical client emulatesrestartby terminating the debug adapter first and then launching it anew. - Restart
Frame - The request restarts execution of the specified stack frame.
The debug adapter first sends the response and then a
stoppedevent (with reasonrestart) after the restart has completed. Clients should only call this request if the corresponding capabilitysupportsRestartFrameis true. - Reverse
Continue - The request resumes backward execution of all threads. If the debug adapter supports single thread execution (see capability
supportsSingleThreadExecutionRequests), setting thesingleThreadargument to true resumes only the specified thread. If not all threads were resumed, theallThreadsContinuedattribute of the response should be set to false. Clients should only call this request if the corresponding capabilitysupportsStepBackis true. - RunIn
Terminal - This request is sent from the debug adapter to the client to run a command in a terminal.
This is typically used to launch the debuggee in a terminal provided by the client.
This request should only be called if the corresponding client capability
supportsRunInTerminalRequestis true. Client implementations ofrunInTerminalare free to run the command however they choose including issuing the command to a command line interpreter (aka ‘shell’). Argument strings passed to therunInTerminalrequest must arrive verbatim in the command to be run. As a consequence, clients which use a shell are responsible for escaping any special shell characters in the argument strings to prevent them from being interpreted (and modified) by the shell. Some users may wish to take advantage of shell processing in the argument strings. For clients which implementrunInTerminalusing an intermediary shell, theargsCanBeInterpretedByShellproperty can be set to true. In this case the client is requested not to escape any special shell characters in the argument strings. - Scopes
- The request returns the variable scopes for a given stack frame ID.
- SetBreakpoints
- Sets multiple breakpoints for a single source and clears all previous breakpoints in that source.
To clear all breakpoint for a source, specify an empty array.
When a breakpoint is hit, a
stoppedevent (with reasonbreakpoint) is generated. - SetData
Breakpoints - Replaces all existing data breakpoints with new data breakpoints.
To clear all data breakpoints, specify an empty array.
When a data breakpoint is hit, a
stoppedevent (with reasondata breakpoint) is generated. Clients should only call this request if the corresponding capabilitysupportsDataBreakpointsis true. - SetException
Breakpoints - The request configures the debugger’s response to thrown exceptions. Each of the
filters,filterOptions, andexceptionOptionsin the request are independent configurations to a debug adapter indicating a kind of exception to catch. An exception thrown in a program should result in astoppedevent from the debug adapter (with reasonexception) if any of the configured filters match. Clients should only call this request if the corresponding capabilityexceptionBreakpointFiltersreturns one or more filters. - SetExpression
- Evaluates the given
valueexpression and assigns it to theexpressionwhich must be a modifiable l-value. The expressions have access to any variables and arguments that are in scope of the specified frame. Clients should only call this request if the corresponding capabilitysupportsSetExpressionis true. If a debug adapter implements bothsetExpressionandsetVariable, a client usessetExpressionif the variable has anevaluateNameproperty. - SetFunction
Breakpoints - Replaces all existing function breakpoints with new function breakpoints.
To clear all function breakpoints, specify an empty array.
When a function breakpoint is hit, a
stoppedevent (with reasonfunction breakpoint) is generated. Clients should only call this request if the corresponding capabilitysupportsFunctionBreakpointsis true. - SetInstruction
Breakpoints - Replaces all existing instruction breakpoints. Typically, instruction breakpoints would be set from a disassembly window.
To clear all instruction breakpoints, specify an empty array.
When an instruction breakpoint is hit, a
stoppedevent (with reasoninstruction breakpoint) is generated. Clients should only call this request if the corresponding capabilitysupportsInstructionBreakpointsis true. - SetVariable
- Set the variable with the given name in the variable container to a new value. Clients should only call this request if the corresponding capability
supportsSetVariableis true. If a debug adapter implements bothsetVariableandsetExpression, a client will only usesetExpressionif the variable has anevaluateNameproperty. - Source
- The request retrieves the source code for a given source reference.
- Stack
Trace - The request returns a stacktrace from the current execution state of a given thread.
A client can request all stack frames by omitting the startFrame and levels arguments. For performance-conscious clients and if the corresponding capability
supportsDelayedStackTraceLoadingis true, stack frames can be retrieved in a piecemeal way with thestartFrameandlevelsarguments. The response of thestackTracerequest may contain atotalFramesproperty that hints at the total number of frames in the stack. If a client needs this total number upfront, it can issue a request for a single (first) frame and depending on the value oftotalFramesdecide how to proceed. In any case a client should be prepared to receive fewer frames than requested, which is an indication that the end of the stack has been reached. - Start
Debugging - This request is sent from the debug adapter to the client to start a new debug session of the same type as the caller.
This request should only be sent if the corresponding client capability
supportsStartDebuggingRequestis true. A client implementation ofstartDebuggingshould start a new debug session (of the same type as the caller) in the same way that the caller’s session was started. If the client supports hierarchical debug sessions, the newly created session can be treated as a child of the caller session. - Step
Back - The request executes one backward step (in the given granularity) for the specified thread and allows all other threads to run backward freely by resuming them.
If the debug adapter supports single thread execution (see capability
supportsSingleThreadExecutionRequests), setting thesingleThreadargument to true prevents other suspended threads from resuming. The debug adapter first sends the response and then astoppedevent (with reasonstep) after the step has completed. Clients should only call this request if the corresponding capabilitysupportsStepBackis true. - StepIn
- The request resumes the given thread to step into a function/method and allows all other threads to run freely by resuming them.
If the debug adapter supports single thread execution (see capability
supportsSingleThreadExecutionRequests), setting thesingleThreadargument to true prevents other suspended threads from resuming. If the request cannot step into a target,stepInbehaves like thenextrequest. The debug adapter first sends the response and then astoppedevent (with reasonstep) after the step has completed. If there are multiple function/method calls (or other targets) on the source line, the argumenttargetIdcan be used to control into which target thestepInshould occur. The list of possible targets for a given source line can be retrieved via thestepInTargetsrequest. - Step
InTargets - This request retrieves the possible step-in targets for the specified stack frame.
These targets can be used in the
stepInrequest. Clients should only call this request if the corresponding capabilitysupportsStepInTargetsRequestis true. - StepOut
- The request resumes the given thread to step out (return) from a function/method and allows all other threads to run freely by resuming them.
If the debug adapter supports single thread execution (see capability
supportsSingleThreadExecutionRequests), setting thesingleThreadargument to true prevents other suspended threads from resuming. The debug adapter first sends the response and then astoppedevent (with reasonstep) after the step has completed. - Terminate
- The
terminaterequest is sent from the client to the debug adapter in order to shut down the debuggee gracefully. Clients should only call this request if the capabilitysupportsTerminateRequestis true. Typically a debug adapter implementsterminateby sending a software signal which the debuggee intercepts in order to clean things up properly before terminating itself. Please note that this request does not directly affect the state of the debug session: if the debuggee decides to veto the graceful shutdown for any reason by not terminating itself, then the debug session just continues. Clients can surface theterminaterequest as an explicit command or they can integrate it into a two stage Stop command that first sendsterminateto request a graceful shutdown, and if that fails usesdisconnectfor a forceful shutdown. - Terminate
Threads - The request terminates the threads with the given ids.
Clients should only call this request if the corresponding capability
supportsTerminateThreadsRequestis true. - Threads
- The request retrieves a list of all threads.
- Variables
- Retrieves all child variables for the given variable reference. A filter can be used to limit the fetched children to either named or indexed children.
- Write
Memory - Writes bytes to memory at the provided location.
Clients should only call this request if the corresponding capability
supportsWriteMemoryRequestis true.
Traits
- Request
- Request is a request, with associated command, and argument and response types.