pub enum Goto {}Expand description
The request sets the location where the debuggee will continue to run.
This makes it possible to skip the execution of code or to execute code again.
The code between the current location and the goto target is not executed but skipped.
The debug adapter first sends the response and then a stopped event with reason goto.
Clients should only call this request if the corresponding capability supportsGotoTargetsRequest is true (because only then goto targets exist that can be passed as arguments).